@@ -1,4 +1,4 @@
-/* vi: ts=8 sts=4 sw=4
+/*
 
     kicontheme.cpp: Lowlevel icon theme handling.
 
@@ -13,6 +13,7 @@
 
 #include "debug.h"
 
+#include <KColorSchemeManager>
 #include <KConfigGroup>
 #include <KLocalizedString> // KLocalizedString::localizedFilePath. Need such functionality in, hmm, QLocale? QStandardPaths?
 #include <KSharedConfig>
@@ -34,9 +35,11 @@
 #include <array>
 #include <cmath>
 
+#include "config.h"
+
 Q_GLOBAL_STATIC(QString, _themeOverride)
 
-#ifdef Q_OS_ANDROID
+#if !USE_BreezeIcons
 
 // on Android we are marked as porting AID, don't mess with theming
 void KIconTheme::initTheme()
@@ -53,6 +56,16 @@ static bool initThemeUsed = false;
 // startup function to set theme once the app got constructed
 static void initThemeHelper()
 {
+    // make sure we add application install path to search path, for e.g. bundles on Windows
+    if (initThemeUsed) {
+        // do that similar to QCoreApplicationPrivate::appendApplicationPathToLibraryPaths() with minimal extra API use
+        QString path = QCoreApplication::applicationFilePath();
+        path.truncate(path.lastIndexOf(QLatin1Char('/')));
+        if (const QString ourPath = path + QStringLiteral("/kiconthemes6"); QFile::exists(ourPath)) {
+            QCoreApplication::addLibraryPath(ourPath);
+        }
+    }
+
     // Makes sure the icon theme fallback is set to breeze or one of its
     // variants. Most of our apps use "lots" of icons that most of the times
     // are only available with breeze, we still honour the user icon theme
@@ -86,6 +99,9 @@ static void initThemeHelper()
     // Tell KIconTheme about the theme, in case KIconLoader is used directly
     *_themeOverride() = themeToUse;
     qCDebug(KICONTHEMES) << "KIconTheme::initTheme() enforces the icon theme:" << themeToUse;
+
+    // follow the system color, construct the global manager for that
+    (void)KColorSchemeManager::instance();
 }
 Q_COREAPP_STARTUP_FUNCTION(initThemeHelper)
 
@@ -338,6 +354,11 @@ KIconTheme::KIconTheme(const QString &name, const QString &appName, const QStrin
     // local embedded icons have preference
     icnlibs << QStringLiteral(":/icons");
 
+#ifdef Q_OS_ANDROID
+    // Android icon theme installed by Kirigami
+    icnlibs << QStringLiteral("assets:/qml/org/kde/kirigami");
+#endif
+
     // global icons
     icnlibs += QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("icons"), QStandardPaths::LocateDirectory);
 
